@@ -113,6 +113,109 @@ class Node:
         """
         return cls(Tuple(elements), **kwargs)
 
+    def inject(self, path, elem):
+        """Inject new nodes or replace nodes in an exisisting schema.
+
+        The original object is not altered, but a new schema is created instead
+        with the same nodes (except for the injection).
+
+        :param path: a tuple of :code:`str` and :code:`int` to indicate the
+            place to modify. Use the names of record fields and the index of
+            tuple fields and unions alternatives.
+        :param elem: the element to insert at :code:`path`
+        :returns: a fresh schema of the same structure as :code:`self` with due
+            modifications.
+
+        Example:
+
+            >>> s1 = Node.of_record({
+                "foo": Node.of_tuple([
+                    Node.of_atom(AtomType.INT, description="width"),
+                    Node.of_atom(AtomType.INT, description="height"),
+                ]),
+                "bar": Node.of_atom(AtomType.STR),
+            })
+            >>> s2 = s1.inject(("foo", 2), Node.of_atom(AtomType.INT, description="depth"))
+            >>> describe(s1)
+            foo: 
+                - width
+                    value of type int
+                - height
+                    value of type int
+            bar: 
+                value of type str
+            >>> describe(s2)
+            foo: 
+                - width
+                    value of type int
+                - height
+                    value of type int
+                - depth
+                    value of type int
+            bar: 
+                value of type str
+        """
+        from .edit import Injecter
+
+        if not path:
+            raise ValueError("You cannot delete with an empty path.")
+
+        return Injecter().visit(self, path, elem)
+
+    def delete(self, path):
+        """Remove a node from an exisisting schema.
+
+        The original object is not altered, but a new schema is created instead
+        with the same nodes (except for the deletion).
+
+        :param path: a tuple of :code:`str` and :code:`int` to indicate the
+            place to modify. Use the names of record fields and the index of
+            tuple fields and unions alternatives.
+        :returns: a fresh schema of the same structure as :code:`self` with due
+            modifications.
+
+        Example:
+
+            >>> s1 = Node.of_record({
+                "foo": Node.of_tuple([
+                    Node.of_atom(AtomType.INT, description="width"),
+                    Node.of_atom(AtomType.INT, description="height"),
+                    Node.of_atom(AtomType.INT, description="depth"),
+                ]),
+                "bar": Node.of_atom(AtomType.STR),
+            })
+            >>> s2 = s1.delete(("foo", 2))
+            >>> describe(s1)
+            foo: 
+                - width
+                    value of type int
+                - height
+                    value of type int
+                - depth
+                    value of type int
+            bar: 
+                value of type str
+            >>> describe(s2)
+            foo: 
+                - width
+                    value of type int
+                - height
+                    value of type int
+            bar: 
+                value of type str
+        """
+        from .edit import Deleter
+
+        if not path:
+            raise ValueError("You cannot delete with an empty path.")
+
+        return Deleter().visit(self, path)
+
+    def copy(self):
+        "Deep copy of the schema."
+        from .visitor import CopyingVisitor
+        return CopyingVisitor().visit(self)
+
 
 class AtomType(Enum):
     "Kind of atomic value."
