@@ -1,12 +1,21 @@
+"Generate template data from a schema."
+
 from .schema import AtomType
 from .visitor import Visitor
 
 
 def template(schema):
+    "Generate a template from :code:`schema`"
+
     return Templater().template_node(schema)
 
 
 class Templater(Visitor):
+    """Visitor implementing templating.
+
+    You should probably be using :func:`template` instead.
+    """
+
     def template_node(self, value):
         data = self.visit(value)
 
